Installation
====================

This software was tested with Python 3.8.5. Some libraries that were used do not exist in earlier version of Python.

Eventually, this should be installable with
.. sourcecode::

    pip install f3ast

For now, install in editable (developer) mode by navigating to the folder root directory and running:
.. sourcecode::

    pip install -e . --user

For now, install from requirements. Navigate with terminal to the folder root directory and run:
.. sourcecode::

    pip install -r requirements.txt